use 5.20.0;
use warnings;

package Map::Metro::Standard {
$Map::Metro::Standard::VERSION = '0.1495';
use Syntax::Collector q/
        use feature 0 ':5.20';
        use warnings 0;
        use true 0;
        use experimental 0 'postderef';
    /;
}

1;
